<template>
    <div class="container">
        <div class="header">
            <div class="title">
                <i class="title-icon"></i>
                <span class="title-text">养护巡查统计</span>
            </div>
            <i class="back-icon" @click="handleReset"></i>
        </div>
        <div class="search">
            <!-- <el-date-picker
                v-model="date"
                type="daterange"
                range-separator="至"
                start-placeholder="开始日期"
                end-placeholder="结束日期"
                value-format="yyyy-MM-dd"
                @change="changeYear"
                style="margin-right: 10px"
            >
            </el-date-picker> -->
            <el-date-picker
                v-model="startTime"
                type="date"
                placeholder="请选择开始日期"
                value-format="yyyy-MM-dd"
            >
            </el-date-picker>
            <el-date-picker
                v-model="endTime"
                type="date"
                placeholder="请选择结束日期"
                value-format="yyyy-MM-dd"
            >
            </el-date-picker>
            <el-button size="small" @click="findinfo" type="primary">查询</el-button>
            <el-button size="small" @click="reset" type="plain"> 重置 </el-button>
        </div>
        <div class="table">
            <el-table
                :data="tableData"
                stripe
                v-loading="loading"
                @row-click="hanldeRowClick"
                @cell-click="handleCellClick"
                header-cell-class-name="custom-header-cell"
                cell-class-name="custom-cell"
            >
                <el-table-column label="序号" type="index" width="70" align="center">
                </el-table-column>
                <el-table-column width="160" align="center" prop="name" label="名称">
                    <template v-slot="{row}">
                        <i class="el-icon-arrow-down" style="margin-right: 10px"></i>
                        {{ row.name }}
                    </template>
                </el-table-column>
                <el-table-column
                    align="center"
                    prop="dayCount"
                    label="日巡检工单数量"
                    column-key="1"
                >
                    <template v-slot="{row}">
                        {{ utils.thousandBit(row.dayCount) }}
                    </template>
                </el-table-column>
                <el-table-column
                    align="center"
                    prop="nightCount"
                    label="夜巡检工单数量"
                    column-key="3"
                >
                    <template v-slot="{row}">
                        {{ utils.thousandBit(row.nightCount) }}
                    </template></el-table-column
                >
                <el-table-column
                    align="center"
                    prop="timeOutCount"
                    label="超时工单数量"
                    column-key="4"
                >
                    <template v-slot="{row}">
                        {{ utils.thousandBit(row.timeOutCount) }}
                    </template></el-table-column
                >
                <el-table-column
                    align="center"
                    prop="fristStepCount"
                    label="创建巡检任务"
                    column-key="5"
                >
                    <template v-slot="{row}">
                        {{ utils.thousandBit(row.fristStepCount) }}
                    </template></el-table-column
                >
                <el-table-column
                    align="center"
                    prop="secondStepCount"
                    label="接受巡检任务"
                    column-key="6"
                >
                    <template v-slot="{row}">
                        {{ utils.thousandBit(row.secondStepCount) }}
                    </template>
                </el-table-column>
                <el-table-column
                    align="center"
                    prop="thirdStepCount"
                    label="完成巡检任务"
                    column-key="2"
                >
                    <template v-slot="{row}">
                        {{ utils.thousandBit(row.thirdStepCount) }}
                    </template>
                </el-table-column>
                <el-table-column
                    align="center"
                    prop="seventhStepCount"
                    label="转办"
                    column-key="7"
                >
                    <template v-slot="{row}">
                        {{ utils.thousandBit(row.seventhStepCount) }}
                    </template>
                </el-table-column>
                <el-table-column
                    align="center"
                    prop="fourthStepCount"
                    label="确认无病害"
                    column-key="8"
                >
                    <template v-slot="{row}">
                        {{ utils.thousandBit(row.fourthStepCount) }}
                    </template>
                </el-table-column>
                <el-table-column
                    align="center"
                    prop="fifthStepCount"
                    label="填写病害"
                    column-key="9"
                >
                    <template v-slot="{row}">
                        {{ utils.thousandBit(row.fifthStepCount) }}
                    </template>
                </el-table-column>
                <el-table-column
                    align="center"
                    prop="sixthStepCount"
                    label="拒绝巡检"
                    column-key="10"
                >
                    <template v-slot="{row}">
                        {{ utils.thousandBit(row.sixthStepCount) }}
                    </template>
                </el-table-column>
                <el-table-column
                    align="center"
                    prop="completeRate"
                    label="完成占比"
                    column-key="10"
                >
                    <template v-slot="{row}">
                        {{ row.completeRate }}
                    </template>
                </el-table-column>
                <el-table-column align="center" prop="allCount" label="总数">
                    <template v-slot="{row}">
                        {{ utils.thousandBit(row.allCount) }}
                    </template>
                </el-table-column>
            </el-table>
            <div class="table-total">
                <span>{{ tableData.length + 1 }}</span>
                <span>总数</span>
                <span>{{ total.dayCount || 0 }}</span>
                <span>{{ total.nightCount || 0 }}</span>
                <span>{{ total.timeOutCount || 0 }}</span>
                <span>{{ total.fristStepCount || 0 }}</span>
                <span>{{ total.secondStepCount || 0 }}</span>
                <span>{{ total.thirdStepCount || 0 }}</span>
                <span>{{ total.seventhStepCount || 0 }}</span>
                <span>{{ total.fourthStepCount || 0 }}</span>
                <span>{{ total.fifthStepCount || 0 }}</span>
                <span>{{ total.sixthStepCount || 0 }}</span>
                <span>-</span>
                <span>{{ total.allCount || 0 }}</span>
            </div>
        </div>
    </div>
</template>

<script>
import utils from '@/utils' // thousandBit格式化千分位
const BigNumber = require('bignumber.js')
import * as echarts from 'echarts'
import moment from 'moment'
export default {
    name: 'maintenanceInspection',
    data() {
        return {
            tableData: [],
            data: [],
            startTime: moment().startOf('year').format('YYYY-MM-DD'),
            endTime: moment().endOf('year').format('YYYY-MM-DD'),
            loading: false,
            cstatus: '',
            date: '',
            total: {},
            utils: utils,
            formInline: {
                companyIds: ['1419863231459102720', '1430734631036129280'],
                companyName: '',
                roadSegmentName: '',
            },
        }
    },
    created() {
        let moment = require('moment')
        let endDate = moment().endOf('year').format('YYYY-MM-DD')
        // 获取当前时间6个月前的时间
        let startDate = moment().startOf('year').format('YYYY-MM-DD')
        this.date = [startDate, endDate]
        this.startTime = startDate
        this.endTime = endDate
        this.loadData()
    },
    watch: {
        tableData(newVal) {
            this.total.dayCount = this.calculation('dayCount', newVal)
            this.total.nightCount = this.calculation('nightCount', newVal)
            this.total.timeOutCount = this.calculation('timeOutCount', newVal)
            this.total.fristStepCount = this.calculation('fristStepCount', newVal)
            this.total.secondStepCount = this.calculation('secondStepCount', newVal)
            this.total.thirdStepCount = this.calculation('thirdStepCount', newVal)
            this.total.seventhStepCount = this.calculation('seventhStepCount', newVal)
            this.total.fourthStepCount = this.calculation('fourthStepCount', newVal)
            this.total.fifthStepCount = this.calculation('fifthStepCount', newVal)
            this.total.sixthStepCount = this.calculation('sixthStepCount', newVal)
            this.total.allCount = this.calculation('allCount', newVal)
        },
    },
    methods: {
        reset() {
            let moment = require('moment')
            let endDate = moment().endOf('year').format('YYYY-MM-DD')
            // 获取当前时间6个月前的时间
            let startDate = moment().startOf('year').format('YYYY-MM-DD')
            this.date = [startDate, endDate]
            this.startTime = startDate
            this.endTime = endTime
            this.loadData()
        },

        format(data) {
            let total = 0
            let money = 0
            data.forEach((item) => {
                total += Number(item.pnameCount)
                money += Number(item.everyMoney)
            })
            console.log(total)
            data.forEach((item) => {
                item.percentage = (item.pnameCount / total) * 100
                item.percent = Number(((item.everyMoney / money) * 100).toFixed(2))
                item.money = (Number(item.everyMoney) / 10000).toFixed(2)
            })
        },
        /**
         * @description: 获取当前日期n个月前的日期
         * @param {String} n 几个月（为负数则表示前面的日期）
         * @return: 日期
         */
        diffMonth(n) {
            var dt = new Date()
            dt.setMonth(dt.getMonth() - Number(n))
            return dt.toLocaleString().replace(/\//g, '-')
        },
        calculation(key, arr) {
            let total = 0
            if (!key || arr.length === 0) return total
            arr.forEach((item) => {
                total += parseInt(item[key])
            })
            if (total === 0) return 0
            return utils.thousandBit(total)
        },
        calculationWY(key, arr) {
            let total = 0
            if (!key || arr.length === 0) return total
            arr.forEach((item) => {
                total += parseFloat((item[key] / 10000).toFixed(4)) * 10000
            })
            if (total === 0) return 0
            return utils.thousandBit(parseFloat((total / 10000).toFixed(4)))
        },
        changeYear(val) {
            if (!val) {
                return this.loadData()
            }
            this.loading = true
            this.$http
                .post(
                    '${yhxt}/siteInspection/v1/getSiteCountvo' +
                        `?startDate=${val[0]}&endDate=${val[1]}`
                )
                .then((res) => {
                    this.tableData = (res && res.status == 200 && res.data) || []
                    this.data = []
                    this.data.push(this.tableData)
                    this.loading = false
                })
        },
        findinfo() {
            let val = this.date
            this.loading = true
            this.$http
                .post(
                    '${yhxt}/siteInspection/v1/getSiteCountvo' +
                        `?startDate=${this.startTime}&endDate=${this.endTime}`
                )
                .then((res) => {
                    this.tableData = (res && res.status == 200 && res.data) || []
                    this.data = []
                    this.data.push(this.tableData)
                    this.loading = false
                })
        },
        handleReset() {
            let length = this.data.length - 1
            if (length === 0) return
            this.tableData = this.data[this.data.length - 2]
            this.data.splice(length, 1)
        },
        hanldeRowClick(row) {
            if (row.chirldren.length == 0) {
                return this.$router.push({
                    name: 'taskManagement',
                    params: {
                        value: row,
                        cstatus: this.cstatus,
                    },
                })
            }
            this.tableData = row.chirldren
            this.data.push(row.chirldren)
        },
        handleCellClick(row, column) {
            this.cstatus = column.columnKey
        },
        loadData() {
            this.loading = true
            let str = ''
            if (this.date) {
                str = `?startDate=${this.date[0]}&endDate=${this.date[1]}`
            }
            this.$http
                .post('${yhxt}/siteInspection/v1/getSiteCountvo' + str)
                .then((res) => {
                    this.tableData = (res && res.status == 200 && res.data) || []
                    this.data = []
                    this.data.push(this.tableData)
                    this.loading = false
                })
                .catch(() => {
                    this.loading = false
                })
        },
    },
}
</script>

<style lang="scss" scoped>
/deep/ .el-date-editor {
    background-color: #103c5d;
    border: none;
}
/deep/ .el-range-separator {
    color: #fff;
}
/deep/ .el-table th.is-leaf {
    background-color: transparent !important;
}
/deep/ .el-table__row {
    background-color: #0b426e !important;
}
/deep/ .el-table__row--striped {
    background-color: #124873 !important;
}
/deep/ .el-table__header-wrapper {
    border-top-left-radius: 10px;
    border-top-right-radius: 10px;
}
/deep/ .el-table__body-wrapper {
    border-bottom-left-radius: 10px;
    border-bottom-right-radius: 10px;
}
/deep/ .el-table {
    background-color: transparent;
}
.container {
    padding: 30px;
    overflow: auto;
    box-sizing: border-box;

    .header {
        height: 59px;
        width: 100%;
        display: flex;
        justify-content: space-between;
        border-bottom: 1px solid #4d7faf;
        .title {
            display: flex;
            height: 34px;
            align-items: center;
            .title-icon {
                display: block;
                width: 28px;
                height: 28px;
                background-image: url('../../assets/img/icon-标题@2x.png');
                background-size: 100% 100%;
            }
            .title-text {
                margin-left: 5px;
                height: 34px;
                font-size: 26px;
                font-family: Microsoft YaHei, Microsoft YaHei;
                font-weight: 700;
                line-height: 34px;
                color: transparent;
                -webkit-background-clip: text;
                background-image: linear-gradient(180deg, #e5f2ff 24%, #1f5c99 100%);
            }
        }
        .back-icon {
            margin-right: 10px;
            cursor: pointer;
            display: block;
            width: 40px;
            height: 40px;
            background-size: 100% 100%;
            background-image: url(../../assets//img/icon-返回@2x.png);
        }
    }
    .search {
        margin-top: 32px;
    }
    .table {
        margin-top: 12px;
        width: 100%;
        /deep/ .custom-header-cell {
            background-color: #145080 !important;
            padding: 15px 0;
            .cell {
                font-size: 18px;
                font-family: Microsoft YaHei, Microsoft YaHei;
                font-weight: 700;
                color: #e7edf0;
            }
        }
        /deep/ .custom-cell {
            padding: 15px 0;
            cursor: pointer;
            .cell,
            div {
                font-size: 16px;
                font-family: Microsoft YaHei, Microsoft YaHei;
                font-weight: 400;
                color: #e5f2ff;
            }
        }
        .table-total {
            display: flex;
            justify-content: center;
            align-items: center;
            height: 64px;
            background-color: #145080;
            border-radius: 10px;
            margin-top: 8px;
            span {
                font-size: 18px;
                font-family: Microsoft YaHei, Microsoft YaHei;
                font-weight: 700;
                color: #e7edf0;
                text-align: center;
                &:nth-child(1) {
                    width: 70px;
                }
                &:nth-child(2) {
                    width: 160px;
                }
                &:not(:nth-child(1)):not(:nth-child(2)) {
                    flex: 1;
                }
            }
        }
    }
    .charts {
        margin-top: 32px;
        display: flex;
        .charts-border {
            position: relative;
            height: 507px;
            flex: 1;
            background-size: 100% 100%;
            background-image: url('../../assets/img/框@2x.png');
            .charts_title {
                display: flex;
                height: 24px;
                align-items: center;
                position: absolute;
                top: 30px;
                left: 20px;
            }
            .charts_title-icon {
                display: block;
                width: 20px;
                height: 20px;
                background-size: 100% 100%;
                background-image: url('../../assets/img/icon-饼图@2x.png');
            }
            .clumn-icon {
                background-image: url('../../assets/img/icon-柱图@2x.png');
            }
            .charts_title-text {
                margin-left: 5px;
                height: 24px;
                font-size: 18px;
                font-family: Microsoft YaHei, Microsoft YaHei;
                font-weight: 700;
                line-height: 24px;
                color: transparent;
                -webkit-background-clip: text;
                background-image: linear-gradient(180deg, #e5f2ff 24%, #1f5c99 100%);
            }
        }
    }
}
</style>
